/***************************************************************************
                          callbacks.c  -  description
                             -------------------
    begin                : Tue Feb 6 2001
    copyright            : (C) 2001 by Felix Gertz
    email                : felix_gertz@das-fluppt.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/



#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "pronews.h"
#include "statusbar.h"
#include "catch.h"
#include "user.h"

/*************************************************************
* on_onoff_activate                                          *
**************************************************************
* Setzt die globale Variable onoff_status.                   *
* Beim online gehen werden die News aktuallisiert.           *
*************************************************************/

void
on_onoff_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{	
	unsigned char changed=0;
	int ret;

	if(!onoff_status)
	{
		onoff_status=1;
		statusbar_refresh();
		changed=1;
		if(first_time || no_first_file())
		{
			char content[20480];
			int laenge=0;
			
			ret=get_file(content);
			ret=get_length(&laenge);
			if(ret)
			{
				if(ret==1000) error_window("Fehlerhafte URL!");
				else error_window("Keine Verbindung zum Server!");		
				onoff_status=0;
				statusbar_refresh();		
				return;
			}
			
			save_first();
			
			save_file(content);
			save_length(laenge);
			
			first_time=0;
			refresh_clist();
		} else
		news_refresh(NULL,NULL);
	}
	if(onoff_status && !changed)
	{
		onoff_status=0;
		statusbar_refresh();
	}
}

void quit_function( GtkWidget *widget, gpointer data )
{
	gtk_main_quit();
}

gint delete_event( GtkWidget *widget, GdkEvent *event, gpointer data )
{
	return(TRUE);
}

void widget_destroy(GtkWidget *widget, GtkWidget *gonner)
{
	gtk_widget_destroy(gonner);
}

/*************************************************************
* selection_made                                             *
**************************************************************
* Wenn in der CList eine Selection gemacht wurde,            *
* wird die URL der Schlagzeile ermittelt und im Browser      *
* dargestellt.                                               *
*************************************************************/

void selection_made( GtkWidget      *clist,
                     gint            row,
                     gint            column,
                     GdkEventButton *event,
                     gpointer        data )
{
		char command_string[255];
		int size;
		
		get_lines(3,&size);
		
		strcpy(command_string,browser_file);
		strcat(command_string," ");
		strcat(command_string,data_array[row]);
		strcat(command_string," &");
		
		system(command_string);

    return;
}

void open_config_window(GtkWidget *widget, gpointer data)
{
	GtkWidget *config_window;
	config_window = create_config_window();
	gtk_widget_show (config_window);
	return;
}

void open_about_window(GtkWidget *widget, gpointer data)
{
	GtkWidget *about_window;
	about_window = create_about_window();
	gtk_widget_show (about_window);
	return;
}

/*************************************************************
* gint news_refresh                                          *
**************************************************************
* Returns <                                                  *
* 0: Nichts getan oder Fehler                                *
* 1: Neue News                                               *
**************************************************************
* Schaut nach neuen News und aktuallisiert bei Erfolg        *
* die CList.                                                 *
*************************************************************/

gint news_refresh( GtkWidget *widget, gpointer data )
{
	int ret;
	
	if(onoff_status)
	{
		ret=new_news();
		if(ret==1)
		{
			GtkWidget *window1;
			refresh_clist();
			window1 = create_window1 ("Neue News!","Es gibt neue News!");
	  	gtk_widget_show (window1);
			return 1;
		}
		else if (ret && ret!=1)
		{
			if(ret==1000) error_window("Fehlerhafte URL!");
			else error_window("Keine Verbindung zum Server!");
			onoff_status=0;
			statusbar_refresh();
		}
	}
	else {
		error_window("Du bist nicht online!");
	}
	return 0;
}

void fill_clist()
{
    int size,i;
    char **clist_entry;
	
    get_lines(1,&size);

    clist_entry = g_new0(gchar*, size);

    for(i=0;i<size;i++) {
    	clist_entry[0] = g_strdup(data_array[i]);
			gtk_clist_append(GTK_CLIST(clist), clist_entry);
			}
			
    return;
}

void refresh_clist()
{
	gtk_clist_clear(GTK_CLIST(clist));
	fill_clist();
}

/*************************************************************
* get_config_defaults                                        *
**************************************************************
* Schreibt die default_config und zeigt sie im config_window *
* an.                                                        *
*************************************************************/

void get_config_defaults( GtkWidget *widget, gpointer data )
{
	char akt_buffer[10];
	set_default_config();
	pronews_config_init();
	
	if(!onoff_status_default) gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton1),FALSE);
	else gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(checkbutton1),TRUE);
	gtk_entry_set_text (GTK_ENTRY (entry_browser), browser_file);
	gtk_entry_set_text (GTK_ENTRY (entry_adr), newsfile_path);
	sprintf(akt_buffer,"%d",akt_rate);
  gtk_entry_set_text (GTK_ENTRY (entry_akt), akt_buffer);

  statusbar_refresh();

}

/*************************************************************
* set_new_config                                             *
**************************************************************
* Schreibt die config aus dem config_window.                 *
*************************************************************/

void set_new_config( GtkWidget *widget,gpointer data)
{
	FILE *data_file;
	char *configfile=NULL;
	
	if(strtol(gtk_entry_get_text(GTK_ENTRY(entry_akt)),NULL,10) < 180)
	{
		error_window("Aktualisierungsrate < 180");
	}
	else
	{
		configfile=get_homedir();
		strcat(configfile,"/.pronews/configfile");
	
		if((data_file = fopen(configfile,"w")) == NULL) {
			printf("Kann nicht ffnen!\n");
			} else {
			if (GTK_TOGGLE_BUTTON (checkbutton1)->active) fprintf(data_file,"1\n");
			else fprintf(data_file,"0\n");
		
			fprintf(data_file,"%s\n",gtk_entry_get_text( GTK_ENTRY (entry_akt) ));
			fprintf(data_file,"%s\n",gtk_entry_get_text( GTK_ENTRY (entry_adr) ));
			fprintf(data_file,"%s\n",gtk_entry_get_text( GTK_ENTRY (entry_browser) ));
			fclose(data_file);
			}
		
		pronews_config_init();
		statusbar_refresh();
		
		widget_destroy(NULL,config_window);
	}
}

gint refresh_news_interval()
{
	if(onoff_status)
	{
		news_refresh(NULL,NULL);
	}
	return 1;
}

void error_window(char message[])
{
		GtkWidget *window1;
		window1 = create_window1 ("Error!",message);
	  gtk_widget_show (window1);
}